==> live-normal-service-api-0.4.9-20220415.090115-7-sources.jar: cn/com/duiba/live/normal/service/api/dto/oto/cust/OtoCustomerPageDto.java <==
package cn.com.duiba.live.normal.service.api.dto.oto.cust;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * @author xiongkai
 * @version 1.0
 * @date 2022-01-11 20:08
 */
@Data
public class OtoCustomerPageDto implements Serializable {

    private static final long serialVersionUID = -6352158074729359750L;

    /**
     * 客户id
     */
    private Long custId;

    /**
     * 客户名称
     */
    private String custName;

    /**
     * 客户价值
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.ext.OtoCustValueEnum
     */
    private Integer custValue;

    /**
     * 跟进客户权重
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.follow.OtoCustFollowWeightEnum
     */
    private Integer followWeight;

    /**
     * 上次跟进时间
     */
    private Date lastFollowTime;

    /**
     * 跟进状态
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.follow.OtoCustFollowStatusEnum
     */
    private Integer followStatus;

    /**
     * 跟进次数 = 打电话次数 + 面访次数 + 参观次数
     */
    private Integer followTimes;

    /**
     * 上次分配时间
     */
    private Date lastAssignTime;

    /**
     * 分配类型
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.follow.OtoCustAssignTypeEnum
     */
    private Integer assignType;

    /**
     * 标签
     */
    private String tags;

    /**
     * 是否为星标客户
     * @see cn.com.duiba.live.normal.service.api.enums.BooleanEnum
     */
    private Integer custStar;

    /**
     * 流程组状态
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.CustFlowEnum
     */
    private Integer custFlow;
}

==> live-normal-service-api-0.4.67-20220920.013542-11-sources.jar: cn/com/duiba/live/normal/service/api/dto/oto/cust/OtoCustomerPageDto.java <==
package cn.com.duiba.live.normal.service.api.dto.oto.cust;

import cn.com.duiba.live.normal.service.api.enums.oto.cust.CustSourceEnum;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * @author xiongkai
 * @version 1.0
 * @date 2022-01-11 20:08
 */
@Data
public class OtoCustomerPageDto implements Serializable {

    private static final long serialVersionUID = -6352158074729359750L;

    /**
     * 客户id
     */
    private Long custId;

    /**
     * 客户名称
     */
    private String custName;

    /**
     * 客户价值
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.ext.OtoCustValueEnum
     */
    private Integer custValue;

    /**
     * 跟进客户权重
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.follow.OtoCustFollowWeightEnum
     */
    private Integer followWeight;

    /**
     * 上次跟进时间
     */
    private Date lastFollowTime;

    /**
     * 跟进状态
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.follow.OtoCustFollowStatusEnum
     */
    private Integer followStatus;

    /**
     * 跟进次数 = 打电话次数 + 面访次数 + 参观次数
     */
    private Integer followTimes;

    /**
     * 上次分配时间
     */
    private Date lastAssignTime;

    /**
     * 分配类型
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.follow.OtoCustAssignTypeEnum
     */
    private Integer assignType;

    /**
     * 标签
     */
    private String tags;

    /**
     * 是否为星标客户
     * @see cn.com.duiba.live.normal.service.api.enums.BooleanEnum
     */
    private Integer custStar;

    /**
     * 流程组状态
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.CustFlowEnum
     */
    private Integer custFlow;

    /**
     * @see CustSourceEnum
     */
    private Integer custSource;

    /**
     * 客户行为
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.CustActionTypeEnum
     */
    private String custActionType;

    /**
     * 客户系数
     */
    private Integer custCoefficient;

    /**
     * 手机号归属地
     */
    private String custArea;
}
